import { isFunction } from 'lodash';
import { createFixer } from './fixer';
export const createRuleManager = (appliedMarkdown) => {
    const fixer = createFixer();
    const allReportedData = [];
    const getReportData = () => {
        return allReportedData;
    };
    const getAllFixes = () => {
        return allReportedData
            .filter((item) => {
            return isFunction(item.fix);
        })
            .map((item) => {
            const fix = item.fix(fixer);
            return {
                ...fix,
                targetRule: item.name
            };
        });
    };
    const createRuleContext = (ruleConfig, data) => {
        const { rule, options } = ruleConfig;
        const report = (option) => {
            const location = option.loc;
            const markStart = Math.max(0, location.start.offset - 5);
            const markEnd = Math.min(appliedMarkdown.length, location.end.offset + 5);
            allReportedData.push({
                ...option,
                content: appliedMarkdown.slice(markStart, markEnd),
                name: rule.meta.name
            });
        };
        return {
            report,
            options: options || {},
            ...data
        };
    };
    return {
        getReportData,
        getAllFixes,
        createRuleContext
    };
};
//# sourceMappingURL=rule-manager.js.map